@@ -1,7 +1,7 @@
 /*
  * DMNTK - Decision Model and Notation Toolkit
-
- * FEEL parser.
+ *
+ * FEEL definitions.
  *
  * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
  *
@@ -14,11 +14,4 @@
  * SOFTWARE.
  */
 
-
-#[cfg(test)]
-mod tests {
-    #[test]
-    fn it_works() {
-        assert_eq!(2 + 2, 4);
-    }
-}
+//! `FEEL` definitions.
